==> iform-0.0.1.tar.gz: lib/component/iform_enum.dart <==
enum IFLayoutAlign{
  FULL_ROW,
  WRAP,
  NEXT_LINE
}
extension IFLayoutAlignExt on IFLayoutAlign{
  int value(){
    switch(this){
      case IFLayoutAlign.FULL_ROW: return 1;
      case IFLayoutAlign.WRAP: return 2;
      case IFLayoutAlign.NEXT_LINE: return 3;
    }
  }
}

enum IFOrientationAlign{
  VERTICAL,
  HORIZONTAL
}
extension IFOrientationAlignExt on IFOrientationAlign{
  int value(){
    switch(this){
      case IFOrientationAlign.HORIZONTAL: return 1;
      case IFOrientationAlign.VERTICAL: return 2;
    }
  }
}

enum IFHorizontalAlign{
  LEFT,
  RIGHT,
  CENTER,
  JUSTIFIED
}
extension IFHorizontalAlignExt on IFHorizontalAlign{
  int value(){
    switch(this){
      case IFHorizontalAlign.LEFT: return 0;
      case IFHorizontalAlign.CENTER: return 1;
      case IFHorizontalAlign.RIGHT: return 2;
      case IFHorizontalAlign.JUSTIFIED: return 3;
    }
  }
}

enum IFVerticalAlign{
  CENTER,
  TOP
}
extension IFVerticalAlignExt on IFVerticalAlign{
  int value(){
    switch(this){
      case IFVerticalAlign.CENTER: return 0;
      case IFVerticalAlign.TOP: return 1;
    }
  }
}

enum IFFontBoldItalic{
  BOLD,
  ITALIC,
  BOTH
}
extension IFFontBoldItalicExt on IFFontBoldItalic{
  int value(){
    switch(this){
      case IFFontBoldItalic.BOLD: return 1;
      case IFFontBoldItalic.ITALIC: return 2;
      case IFFontBoldItalic.BOTH: return 3;
    }
  }
}

enum IFInputAllowType{
  AlphanumericWithoutSpace1001,
  AlphanumericWithSpace1002,
  AlphabetAZAndSpecialChars1003,
  AlphanumericWithSpecialChars1004,
  Numeric1005,
  AlphabetAZWithoutSpace1006,
  AlphabetAZWithSpace1007,
  Email1008,
  Password1009,
  PasswordMask1010,
  Phone1011,
  Decimal1012,
  MsiaIC1013
}
IFInputAllowType inputAllowTypeValueOf(int value){
  switch(value){
    case 1001: return IFInputAllowType.AlphanumericWithoutSpace1001;
    case 1002: return IFInputAllowType.AlphanumericWithSpace1002;
    case 1003: return IFInputAllowType.AlphabetAZAndSpecialChars1003;
    case 1004: return IFInputAllowType.AlphanumericWithSpecialChars1004;
    case 1005: return IFInputAllowType.Numeric1005;
    case 1006: return IFInputAllowType.AlphabetAZWithoutSpace1006;
    case 1007: return IFInputAllowType.AlphabetAZWithSpace1007;
    case 1008: return IFInputAllowType.Email1008;
    case 1009: return IFInputAllowType.Password1009;
    case 1010: return IFInputAllowType.PasswordMask1010;
    case 1011: return IFInputAllowType.Phone1011;
    case 1012: return IFInputAllowType.Decimal1012;
    case 1013: return IFInputAllowType.MsiaIC1013;
    default: return null;
  }
}
extension IFInputAllowTypeExt on IFInputAllowType{
  String regExp(){
    switch(this){
      case IFInputAllowType.AlphanumericWithoutSpace1001: return "a-zA-Z0-9";
      case IFInputAllowType.AlphanumericWithSpace1002: return "a-zA-Z\\s'@\\.\\,/\\-";
      case IFInputAllowType.AlphabetAZAndSpecialChars1003: return "a-zA-Z\\s'@\\.\\,/\\-";
      case IFInputAllowType.AlphanumericWithSpecialChars1004: return "a-zA-Z0-9\\-/";
      case IFInputAllowType.Numeric1005: return "0-9";
      case IFInputAllowType.AlphabetAZWithoutSpace1006: return "A-Za-z";
      case IFInputAllowType.AlphabetAZWithSpace1007: return "A-Za-z\\s";
      case IFInputAllowType.Email1008: return "A-Za-z0-9@\\._";
      case IFInputAllowType.Password1009: return "any";
      case IFInputAllowType.PasswordMask1010: return "any";
      case IFInputAllowType.Phone1011: return "any";
      case IFInputAllowType.Decimal1012: return "any";
      case IFInputAllowType.MsiaIC1013: return "any";
    }
  }
  int value(){
    switch(this){
      case IFInputAllowType.AlphanumericWithoutSpace1001: return 1001;
      case IFInputAllowType.AlphanumericWithSpace1002: return 1002;
      case IFInputAllowType.AlphabetAZAndSpecialChars1003: return 1003;
      case IFInputAllowType.AlphanumericWithSpecialChars1004: return 1004;
      case IFInputAllowType.Numeric1005: return 1005;
      case IFInputAllowType.AlphabetAZWithoutSpace1006: return 1006;
      case IFInputAllowType.AlphabetAZWithSpace1007: return 1007;
      case IFInputAllowType.Email1008: return 1008;
      case IFInputAllowType.Password1009: return 1009;
      case IFInputAllowType.PasswordMask1010: return 1010;
      case IFInputAllowType.Phone1011: return 1011;
      case IFInputAllowType.Decimal1012: return 1012;
      case IFInputAllowType.MsiaIC1013: return 1013;
    }
  }
}

==> iform-0.0.6.tar.gz: lib/component/iform_enum.dart <==
enum IFLayoutAlign{
  FULL_ROW,
  WRAP,
  NEXT_LINE
}
extension IFLayoutAlignExt on IFLayoutAlign{
  int value(){
    switch(this){
      case IFLayoutAlign.FULL_ROW: return 1;
      case IFLayoutAlign.WRAP: return 2;
      case IFLayoutAlign.NEXT_LINE: return 3;
    }
  }
}

enum IFOrientationAlign{
  VERTICAL,
  HORIZONTAL
}
extension IFOrientationAlignExt on IFOrientationAlign{
  int value(){
    switch(this){
      case IFOrientationAlign.HORIZONTAL: return 1;
      case IFOrientationAlign.VERTICAL: return 2;
    }
  }
}

enum IFHorizontalAlign{
  LEFT,
  RIGHT,
  CENTER,
  JUSTIFIED
}
extension IFHorizontalAlignExt on IFHorizontalAlign{
  int value(){
    switch(this){
      case IFHorizontalAlign.LEFT: return 0;
      case IFHorizontalAlign.CENTER: return 1;
      case IFHorizontalAlign.RIGHT: return 2;
      case IFHorizontalAlign.JUSTIFIED: return 3;
    }
  }
}

enum IFVerticalAlign{
  CENTER,
  TOP
}
extension IFVerticalAlignExt on IFVerticalAlign{
  int value(){
    switch(this){
      case IFVerticalAlign.CENTER: return 0;
      case IFVerticalAlign.TOP: return 1;
    }
  }
}

enum IFFontBoldItalic{
  BOLD,
  ITALIC,
  BOTH
}
extension IFFontBoldItalicExt on IFFontBoldItalic{
  int value(){
    switch(this){
      case IFFontBoldItalic.BOLD: return 1;
      case IFFontBoldItalic.ITALIC: return 2;
      case IFFontBoldItalic.BOTH: return 3;
    }
  }
}

enum IFInputAllowType{
  AlphanumericWithoutSpace1001,
  AlphanumericWithSpace1002,
  AlphabetAZAndSpecialChars1003,
  AlphanumericWithSpecialChars1004,
  Numeric1005,
  AlphabetAZWithoutSpace1006,
  AlphabetAZWithSpace1007,
  Email1008,
  Password1009,
  PasswordMask1010,
  Phone1011,
  Decimal1012,
  MsiaIC1013
}
IFInputAllowType inputAllowTypeValueOf(int value){
  switch(value){
    case 1001: return IFInputAllowType.AlphanumericWithoutSpace1001;
    case 1002: return IFInputAllowType.AlphanumericWithSpace1002;
    case 1003: return IFInputAllowType.AlphabetAZAndSpecialChars1003;
    case 1004: return IFInputAllowType.AlphanumericWithSpecialChars1004;
    case 1005: return IFInputAllowType.Numeric1005;
    case 1006: return IFInputAllowType.AlphabetAZWithoutSpace1006;
    case 1007: return IFInputAllowType.AlphabetAZWithSpace1007;
    case 1008: return IFInputAllowType.Email1008;
    case 1009: return IFInputAllowType.Password1009;
    case 1010: return IFInputAllowType.PasswordMask1010;
    case 1011: return IFInputAllowType.Phone1011;
    case 1012: return IFInputAllowType.Decimal1012;
    case 1013: return IFInputAllowType.MsiaIC1013;
    default: return null;
  }
}
extension IFInputAllowTypeExt on IFInputAllowType{
  String regExp(){
    switch(this){
      case IFInputAllowType.AlphanumericWithoutSpace1001: return "a-zA-Z0-9";
      case IFInputAllowType.AlphanumericWithSpace1002: return "a-zA-Z\\s'@\\.\\,/\\-";
      case IFInputAllowType.AlphabetAZAndSpecialChars1003: return "a-zA-Z\\s'@\\.\\,/\\-";
      case IFInputAllowType.AlphanumericWithSpecialChars1004: return "a-zA-Z0-9\\-/";
      case IFInputAllowType.Numeric1005: return "0-9\\._";
      case IFInputAllowType.AlphabetAZWithoutSpace1006: return "A-Za-z";
      case IFInputAllowType.AlphabetAZWithSpace1007: return "A-Za-z\\s";
      case IFInputAllowType.Email1008: return "A-Za-z0-9@\\._";
      case IFInputAllowType.Password1009: return "any";
      case IFInputAllowType.PasswordMask1010: return "any";
      case IFInputAllowType.Phone1011: return "any";
      case IFInputAllowType.Decimal1012: return "any";
      case IFInputAllowType.MsiaIC1013: return "any";
    }
  }
  int value(){
    switch(this){
      case IFInputAllowType.AlphanumericWithoutSpace1001: return 1001;
      case IFInputAllowType.AlphanumericWithSpace1002: return 1002;
      case IFInputAllowType.AlphabetAZAndSpecialChars1003: return 1003;
      case IFInputAllowType.AlphanumericWithSpecialChars1004: return 1004;
      case IFInputAllowType.Numeric1005: return 1005;
      case IFInputAllowType.AlphabetAZWithoutSpace1006: return 1006;
      case IFInputAllowType.AlphabetAZWithSpace1007: return 1007;
      case IFInputAllowType.Email1008: return 1008;
      case IFInputAllowType.Password1009: return 1009;
      case IFInputAllowType.PasswordMask1010: return 1010;
      case IFInputAllowType.Phone1011: return 1011;
      case IFInputAllowType.Decimal1012: return 1012;
      case IFInputAllowType.MsiaIC1013: return 1013;
    }
  }
}
